@@ -1,28 +1,27 @@
 /*
- * Copyright (C) 2014 Stuart Howarth <showarth@marxoft.co.uk>
+ * Copyright (C) 2015 Stuart Howarth <showarth@marxoft.co.uk>
  *
- * This program is free software; you can redistribute it and/or modify it
- * under the terms and conditions of the GNU Lesser General Public License,
- * version 3, as published by the Free Software Foundation.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 3 as
+ * published by the Free Software Foundation.
  *
- * This program is distributed in the hope it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
- * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
- * more details.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software Foundation,
- * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef DOWNLOADMODEL_H
 #define DOWNLOADMODEL_H
 
 #include "download.h"
-#include <QAbstractTableModel>
+#include <QAbstractListModel>
 #include <qdeclarative.h>
 
-class DownloadModel : public QAbstractTableModel
+class DownloadModel : public QAbstractListModel
 {
     Q_OBJECT
 
@@ -49,19 +48,19 @@ public:
     int activeDownloads() const;
 
     int rowCount(const QModelIndex &parent = QModelIndex()) const;
-    int columnCount(const QModelIndex &parent = QModelIndex()) const;
 
-    Q_INVOKABLE QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
+    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
+    Q_INVOKABLE QVariant data(int row, int role = Qt::DisplayRole) const;
 
-    Q_INVOKABLE Download* get(const QModelIndex &index) const;
+    Q_INVOKABLE Download* get(int row) const;
 
-public slots:
+public Q_SLOTS:
     void load();
     void save();
 
     void addDownload(const QUrl &url, const QVariantMap &headers, const QString &fileName);
 
-private slots:
+private Q_SLOTS:
     void onDownloadQueued(Download *download);
     void onDownloadStarted(Download *download);
     void onDownloadPaused(Download *download);
@@ -74,7 +73,7 @@ private:
     void removeDownload(Download *download);
     void startNextDownload();
     
-signals:
+Q_SIGNALS:
     void countChanged();
     void activeDownloadsChanged();
     
